{**********************************************************************
 CodeOcean
 Demo for Package pl_OnGuard.pkg
 This unit is part of CodeTyphon Project (http://www.pilotlogic.com/)
***********************************************************************}
unit uni_RegCommon;

{$mode objfpc}{$H+}

interface

uses
  OnGuard, OgUtil, Classes;

const
  cnInitKey : TKey = ($3E,$C9,$18,$78,$7D,$AC,$AF,$D3,$64,$E0,$BC,$0A,$43,$68,$2C,$F2);

var
  MachineModifier : longint;
  MachineKey : TKey;
  Expires : TDateTime;
  RegistrationInfo : TStringList;

function  IsReleaseCodeValid(const aReleaseCodeString: string;
                             const aSerialNumber : longint;
                             const aKey:TKey;
                             Const anExpires: TDateTime=0) : boolean;
procedure SaveRegistrationInformation (const ReleaseCodeString: string; const SerialNumber : longint);
procedure GetRegistrationInformation (var ReleaseCodeString: string; var SerialNumber : longint);

implementation

uses
  SysUtils;

const
  RegistrationFile = 'REGISTRATION.DAT';

function IsReleaseCodeValid(const aReleaseCodeString: string;
                            const aSerialNumber : longint;
                            const aKey:TKey;
                            Const anExpires: TDateTime=0) : boolean;
var
  CalculatedReleaseCode : TCode;
  S1,S2:string;
begin
  // Create the release code for the data givien
  InitSerialNumberCode(aKey, aSerialNumber, anExpires, CalculatedReleaseCode);
  s2 := BufferToHex(CalculatedReleaseCode, sizeof(CalculatedReleaseCode));

  // Insert spaces in the release code string for easier reading
  System.Insert(' ', s2, 13);
  System.Insert(' ', s2, 09);
  System.Insert(' ', s2, 05);

  S2:=AnsiUpperCase(s2);

  S1:=AnsiUpperCase(aReleaseCodeString);
  result := (s1=s2);
end;

procedure SaveRegistrationInformation (const ReleaseCodeString: string; const SerialNumber : longint);
begin
  // Save the information for the application
  RegistrationInfo := TStringList.Create;
  RegistrationInfo.Add(format('%d',[SerialNumber]));
  RegistrationInfo.Add(ANSIUpperCase(ReleaseCodeString));
  RegistrationInfo.SaveToFile(RegistrationFile);
  RegistrationInfo.Free;
end;

procedure GetRegistrationInformation (var ReleaseCodeString: string; var SerialNumber : longint);
begin
  // Save the information for the application
  if FileExists(RegistrationFile) then begin
    RegistrationInfo := TStringList.Create;
    RegistrationInfo.LoadFromFile(RegistrationFile);
    SerialNumber := StrToInt(RegistrationInfo[0]);
    ReleaseCodeString := RegistrationInfo[1];
    RegistrationInfo.Free;
  end else begin
    SerialNumber := 0;
    ReleaseCodeString := '';
  end;
end;

initialization
  Expires := 0;
  MachineKey := cnInitKey;
  MachineModifier := ABS(CreateMachineID([midUser, midSystem, {midNetwork,} midDrives]));
  ApplyModifierToKeyPrim(MachineModifier,MachineKey,sizeof(MachineKey));
end.


